==> cms-db_v0.6.tar.gz: admin/locales/de/locale_edituser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['edituser'] = array();

$locale['edituser']['title'] = 'Benutzer';
$locale['edituser']['title_root'] = 'Hauptbenutzer';
$locale['edituser']['desc_root'] = 'Der Hauptbenutzer hat Zugriff auf alle Einstellungen. Er wird zum Anlegen und Löschen von Benutzern, sowie zum Änderen der Berechtigungen von Benutzern benötigt!';
$locale['edituser']['title_users'] = 'Benutzerverwaltung';
$locale['edituser']['link_no-users'] = 'Außer der Hautpbenutzer existieren keine Benutzer.';
$locale['edituser']['link_newuser'] = 'Einen neuen Benutzer anlegen';

$locale['edituser']['title_edituser'] = 'Benutzer bearbeiten';
$locale['edituser']['title_newuser'] = 'Benutzer anlegen';
$locale['edituser']['link_user-saved'] = 'zur Benutzerverwaltung';
$locale['edituser']['label_user-pages'] = 'Benutzer darf Seiten bearbeiten';
$locale['edituser']['label_user-files'] = 'Benutzer darf Dateien hochladen und löschen';
$locale['edituser']['label_user-includes'] = 'Benutzer darf Includes bearbeiten';
$locale['edituser']['label_user-template'] = 'Benutzer darf Template bearbeiten';
$locale['edituser']['label_user-gbook'] = 'Benutzer darf Gästebucheinträge löschen';
$locale['edituser']['label_user-stats'] = 'Benutzer darf Statistiken löschen';
$locale['edituser']['desc_users'] = 'Jeder Benutzer darf sein Passwort ändern, sowie Dateiberechtigungen, Speicherplatz und Statistiken einsehen. Kein Benutzer außer der Hauptbenutzer darf Einstellungen verändern.';
$locale['edituser']['desc_error-username'] = 'Ein Benutzer mit diesem Namen existiert schon.';
?>

==> cms-db_v0.6.1.tar.gz: admin/locales/de/locale_edituser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['edituser'] = array();

$locale['edituser']['title'] = 'Benutzer';
$locale['edituser']['title_root'] = 'Hauptbenutzer';
$locale['edituser']['desc_root'] = 'Der Hauptbenutzer hat Zugriff auf alle Einstellungen. Er wird zum Anlegen und Löschen von Benutzern, sowie zum Änderen der Berechtigungen von Benutzern benötigt!';
$locale['edituser']['title_users'] = 'Benutzerverwaltung';
$locale['edituser']['desc_no-users'] = 'Außer dem Hautpbenutzer existieren keine Benutzer.';
$locale['edituser']['link_newuser'] = 'Einen neuen Benutzer anlegen';

$locale['edituser']['title_edituser'] = 'Benutzer bearbeiten';
$locale['edituser']['title_newuser'] = 'Benutzer anlegen';
$locale['edituser']['link_user-saved'] = 'zur Benutzerverwaltung';
$locale['edituser']['label_change-password'] = 'Passwort ändern';
$locale['edituser']['label_user-pages'] = 'Benutzer darf Seiten bearbeiten';
$locale['edituser']['label_user-files'] = 'Benutzer darf Dateien hochladen und löschen';
$locale['edituser']['label_user-includes'] = 'Benutzer darf Includes bearbeiten';
$locale['edituser']['label_user-template'] = 'Benutzer darf Template bearbeiten';
$locale['edituser']['label_user-gbook'] = 'Benutzer darf Gästebucheinträge löschen';
$locale['edituser']['label_user-stats'] = 'Benutzer darf Statistiken löschen';
$locale['edituser']['desc_users'] = 'Jeder Benutzer darf sein Passwort ändern, sowie Dateiberechtigungen, Speicherplatz und Statistiken einsehen. Kein Benutzer außer der Hauptbenutzer darf Einstellungen verändern.';
$locale['edituser']['desc_error-username'] = 'Ein Benutzer mit diesem Namen existiert schon.';
?>
